@@ -28,16 +28,8 @@ pub struct FeeCollect<'info> {
 }
 
 pub fn handler(ctx: Context<FeeCollect>) -> ProgramResult {
-    // Get accounts.
     let fee = &mut ctx.accounts.fee;
     let treasury = &mut ctx.accounts.treasury;
 
-    // Collect lamports fee account to treasury.
-    **fee.to_account_info().try_borrow_mut_lamports()? -= fee.balance;
-    **treasury.to_account_info().try_borrow_mut_lamports()? += fee.balance;
-
-    // Null out collectable fee balance.
-    fee.balance = 0;
-    
-    Ok(())
+    fee.collect(treasury)
 }
